/**
 *******************************************************************************
 * @file  board_init.c
 * @brief Board setting for TS-R-IN32M4-CL2
 * 
 * @note 
 * Copyright 2016 Renesas Electronics Corporation 
 * 
 * @par
 *  This is a sample program. 
 *  Renesas Electronics assumes no responsibility for any losses incurred. 
 * 
 *******************************************************************************
 */
/*============================================================================*/
/* I N C L U D E                                                              */
/*============================================================================*/

#include "board_init.h"

/*============================================================================*/
/* D E F I N E                                                                */
/*============================================================================*/

/*============================================================================*/
/* V A R I A B L E                                                            */
/*============================================================================*/

/*============================================================================*/
/* E X T E R N                                                                */
/*============================================================================*/

/*============================================================================*/
/* S T A T I C   F U N C T I O N   P R O T O T Y P E                          */
/*============================================================================*/

/*============================================================================*/
/* P R O G R A M                                                              */
/*============================================================================*/
/**
 *******************************************************************************
  @brief  board initialize for TS-R-IN32M4-CL2
  @param  none
  @retval none
 *******************************************************************************
*/
void board_init(void)
{
	RIN_GPIO->PM0B    = 0x02;       // P00   Port Output
	RIN_GPIO->PMC0B   = 0x00;       // P01   Port Input
	RIN_GPIO->PFC0B   = 0x00;       // P02   Port Output
	RIN_GPIO->PFCE0B  = 0x00;       // P03   Port Output
	RIN_GPIO->P0B    |= 0xFD;       // P04   Port Output
                                    // P05   Port Output
                                    // P06   Port Output
                                    // P07   Port Output
	
	RIN_GPIO->PM1B   &= 0xF3;       // P10   ----
	RIN_GPIO->PMC1B  &= 0xF3;       // P11   ----
	RIN_GPIO->PFC1B  &= 0xF3;       // P12   Port Output
	RIN_GPIO->PFCE1B &= 0xF3;       // P13   Port Output
                                    // P14   ----
                                    // P15   ----
                                    // P16   ----
                                    // P17   ----
	
	RIN_GPIO->PM2B    = 0x1C;       // P20   Port Output
	RIN_GPIO->PMC2B   = 0x00;       // P21   Port Output
	RIN_GPIO->PFC2B   = 0x00;       // P22   Port Input
	RIN_GPIO->PFCE2B  = 0x00;       // P23   Port Input
	RIN_GPIO->P2B    |= 0x63;       // P24   Port Input
                                    // P25   Port Output
                                    // P26   Port Output
                                    // P27   Port Output

	RIN_GPIO->PM3B   &= 0x03;       // P30   ----
	RIN_GPIO->PMC3B  &= 0x03;       // P31   ----
	RIN_GPIO->PFC3B  &= 0x03;       // P32   Port Output
	RIN_GPIO->PFCE3B &= 0x03;       // P33   Port Output
	RIN_GPIO->P3B    |= 0x0C;       // P34   Port Output
                                    // P35   Port Output
                                    // P36   Port Output
                                    // P37   Port Output

	RIN_GPIO->PM5B    = 0xD0;       // P50   Port Output
	RIN_GPIO->PMC5B   = 0x00;       // P51   Port Output
	RIN_GPIO->PFC5B   = 0x00;       // P52   Port Output
	RIN_GPIO->PFCE5B  = 0x00;       // P53   Port Output
                                    // P54   Port Input
                                    // P55   Port Output
                                    // P56   Port Input
                                    // P57   Port Input
	
	RIN_GPIO->PM6B    = 0x3C;       // P60   Port Output
	RIN_GPIO->PMC6B   = 0x00;       // P61   Port Output
	RIN_GPIO->PFC6B   = 0x00;       // P62   Port Input
	RIN_GPIO->PFCE6B  = 0x00;       // P63   Port Input
	RIN_GPIO->P6B    |= 0x40;       // P64   Port Input
                                    // P65   Port Input
                                    // P66   Port Output
                                    // P67   Port Output

	RIN_GPIO->PM7B    = 0xFF;       // P70-P77    Port Input
	RIN_GPIO->PMC7B   = 0x00;
	
	RIN_RTPORT->RPM0B    = 0x3C;    // RP00  Port Output
	RIN_RTPORT->RPMC0B   = 0x00;    // RP01  Port Output
	RIN_RTPORT->RPFC0B   = 0x00;    // RP02  Port Input
	RIN_RTPORT->RPFCE0B  = 0x00;    // RP03  Port Input
	RIN_RTPORT->RP0B    |= 0x03;    // RP04  Port Input
                                    // RP05  Port Input
                                    // RP06  Port Output
                                    // RP07  Port Output
	
	RIN_RTPORT->RPM1B    = 0xFF;    // RP10-RP17  Port Input
	RIN_RTPORT->RPMC1B   = 0x00;

	RIN_RTPORT->RPM2B    = 0x00;    // RP20-RP27  Port Output
	RIN_RTPORT->RPMC2B   = 0x00;
	RIN_RTPORT->RP2B     = 0xFF;

	RIN_RTPORT->RPM3B    = 0xFF;    // RP30-RP37  Port Input
	RIN_RTPORT->RPMC3B   = 0x00;
}

/**
 *******************************************************************************
  @brief  board initialize for CC-Link IE Field
  @param  none
  @retval none
 *******************************************************************************
*/
void cie_board_init(void)
{
	RIN_GPIO->PMC0B  |= 0xFD;       // P00   Mode 3  CCI_RUNLEDZ
	RIN_GPIO->PFC0B  &=~0xFD;       // P01   ---
	RIN_GPIO->PFCE0B |= 0xFD;       // P02   Mode 3  CCI_DLINKLEDZ
                                    // P03   Mode 3  CCI_ERRLEDZ
                                    // P04   Mode 3  CCI_LERR1LEDZ
                                    // P05   Mode 3  CCI_LERR2LEDZ
                                    // P06   Mode 3  CCI_SDLEDZ
                                    // P07   Mode 3  CCI_RDLEDZ
}

/**
 *******************************************************************************
  @brief  Set LED value
  @param  output	: LED value
  @retval none
 *******************************************************************************
*/
void set_board_led(uint8_t output)
{
	/* LED (D39,D40,D42,D43,D44,D45,D46,D48) */
	RIN_RTPORT->RP2B = ~output;
}

/**
 *******************************************************************************
  @brief  Get LED value
  @param  none
  @retval LED value
 *******************************************************************************
*/
uint8_t get_board_led(void)
{
	/* LED (D39,D40,D42,D43,D44,D45,D46,D48) */
	return ~RIN_RTPORT->RPIN2B;
}

/**
 *******************************************************************************
  @brief  Get general sw value
  @param  none
  @retval General SW value
 *******************************************************************************
*/
uint8_t get_board_sw(void)
{
	/* SW12 */
	return RIN_RTPORT->RPIN3B;
}

/**
 *******************************************************************************
  @brief  Get Baudrate value for CC-Link intelligent device
  @param  none
  @retval Baudrate value
 *******************************************************************************
*/
uint8_t cli_get_baudrate(void)
{
	/* SW11 */
	return ~((RIN_GPIO->PIN6B & 0x3C) >> 2);
}
/**
 *******************************************************************************
  @brief  Get Baudrate value for CC-Link remote device
  @param  none
  @retval Baudrate value
 *******************************************************************************
*/
uint8_t clr_get_baudrate(void)
{
	/* SW10 */
	return ~((RIN_RTPORT->RPIN0B & 0x3C) >> 2);
}

/**
 *******************************************************************************
  @brief  Get Node number for CC-Link IE field
  @param  none
  @retval Node number for CC-Link IE field
 *******************************************************************************
*/
uint8_t cie_get_nodenumber(void)
{
	/* SW3 / SW5 */
	return ~RIN_RTPORT->RPIN1B;
}


/**
 *******************************************************************************
  @brief  Get Network number for CC-Link IE field
  @param  none
  @retval Network number for CC-Link IE field
 *******************************************************************************
*/
uint8_t cie_get_networknumber(void)
{
	/* SW4 / SW6 */
	return ~RIN_GPIO->PIN7B;
}

/**
 *******************************************************************************
  @brief  Get Node number for CC-Link
  @param  none
  @retval Node number for CC-Link
 *******************************************************************************
*/
uint8_t cl_get_nodenumber(void)
{
	/* SW4 / SW6 */
	return ~RIN_GPIO->PIN7B;
}

