/**
 *******************************************************************************
 * @file  dmac.c
 * @brief DMAC driver program
 * 
 * @note 
 * Copyright (C) 2015 Renesas Electronics Corporation 
 * Copyright (C) 2015 Renesas System Design Co., Ltd. 
 * 
 * @par
 *  This is a sample program. 
 *  Renesas Electronics assumes no responsibility for any losses incurred. 
 * 
 *******************************************************************************
 */

/*============================================================================*/
/* I N C L U D E                                                              */
/*============================================================================*/
#include "dmac/dmac.h"

/*============================================================================*/
/* D E F I N E                                                                */
/*============================================================================*/
#define RIN_DMAC		RIN_DMAC3				// DMAC channel

/*===========================================================================*/
/* S T R U C T                                                               */
/*===========================================================================*/

/*============================================================================*/
/* V A R I A B L E                                                            */
/*============================================================================*/

/*============================================================================*/
/* E X T E R N                                                                */
/*============================================================================*/

/*============================================================================*/
/* S T A T I C   F U N C T I O N   P R O T O T Y P E                          */
/*============================================================================*/

/*============================================================================*/
/* P R O G R A M                                                              */
/*============================================================================*/
/**
 ******************************************************************************
  @brief  Memory copy
  @param  dst -- Destination address
  @param  src -- Source      address
  @param  n   -- transaction byte
  @retval dst -- Destination address
 ******************************************************************************
*/
void *dmac_memcpy(void *dst, const void *src, uint32_t n)
{
	//=========================================================
	// Setup parameter
	//=========================================================
	RIN_DMAC->N0DA = (uint32_t)dst;				// Set destination address
	RIN_DMAC->N0SA = (uint32_t)src;				// Set source      address
	RIN_DMAC->N0TB = (uint32_t)n;				// Set transaction byte

	RIN_DMAC->CHCFG = (1 << 22) 				// Block transfer mode
	                | (2 << 16)					// Destination transfer size 32 bit
	                | (2 << 12);				// Source      transfer size 32 bit

	//=========================================================
	// Start DMA transfer
	//=========================================================
	RIN_DMAC->CHCTRL = (1 << 2) 				// Software trigger
	                 | (1 << 0);				// DMA transfer enable
	
	//=========================================================
	// Check transfer finish
	//=========================================================
	while ((RIN_DMAC->CHSTAT & 0x00000004) == 0x00000004) {
	}

	return dst;
}
